@@ -85,9 +85,9 @@ class NavParser:
         super()
         self._nmea_block_buffer = ""
         self._nmea_buffer_flags = {
-            NMEASentectID.RMC: False,
-            NMEASentectID.GGA: False,
-            NMEASentectID.VTG: False
+            NMEASentectID.RMC.value: False,
+            NMEASentectID.GGA.value: False,
+            NMEASentectID.VTG.value: False
         }
         self._points = dict()
         if is_file:
